@@ -1,9 +1,3 @@
-/* Ultrix xdr_functions in libc prevents linking */
-#undef ULTRIX_KLUDGE
-
-/* OSF1 does not want to take the address of structs */
-#undef OSF_KLUDGE
-
 /* Define if the systems has the resultproc_t type. */
 #undef HAVE_RESULTPROC_T
 
